@@ -28,6 +28,7 @@ class OFSMCCSolver:
         q_fuse=None,
         q_sh=None,
         V=None,
+        L=None,
         corpus_material=None,
         explosive_material=None,
         belt_material=None,
@@ -223,8 +224,11 @@ class OFSMCCSolver:
             else:
                 konus = self.get_params_conus(r1=y_coord[i], r2=y_coord[i - 1], x1=x_coord[i], x2=x_coord[i - 1], rho=0)
                 V += konus['V']
+        try:
+            rho = q / V
 
-        rho = q / V
+        except ZeroDivisionError:
+            pass
 
         # Определяем все остальные характеристики
 
@@ -346,12 +350,20 @@ class OFSMCCSolver:
 
         d = p_data['gun']['d']
         fi = 0.57
-        L = np.max(p_data['corpus_coord'][0])
+        sizes = p_data['shell_size']
+        L_corp = sizes['R1'] + sizes['R2'] + sizes['R3'] + sizes['R4'] + sizes['R6'] + sizes['R7'] + sizes['R8']
+        L = L_corp + sizes['R27']
+
         Hg = L - p_data['corpus_coord'][0, 11]
+
         Cq = (q / d**3) * 1e-3
         h0 = p_data['corpus_coord'][0, 11] - xc
         h1 = fi * Hg - 0.16 * d
 
+        sizes = p_data['shell_size']
+        L_corp = sizes['R1'] + sizes['R2'] + sizes['R3'] + sizes['R4'] + sizes['R6'] + sizes['R7'] + sizes['R8']
+        L = L_corp + sizes['R27']
+
         h = h0 + h1
 
         if L <= 4.5 * d:
@@ -386,6 +398,15 @@ class OFSMCCSolver:
     def get_params_for_kontur(self, data, state, xc):
         sizes = data['shell_size']
 
+        # ng = 3 #Количество разбиения ГЧ
+        # nh = ng + 1 #Количество участков головной и цилиндрической частей
+        # nk = 5  #Общее количество участков на снаряде
+        # nfl = 2 # Вид притупления
+        # yint = 0 # Высота носика (0 потому что задаётся отдельным примитивом)
+        # d = sizes['d']  # Калибра снаряда
+        # hb = sizes['R17'] - (d / 2)   # Высота пояска
+        # xct = state['geometry_solver']['L_all'] - xc # Координата центра тяжести (ОТ НОСИКА !!!)
+
         ng = 3 #Количество разбиения ГЧ
         nh = ng + 1 #Количество участков головной и цилиндрической частей
         nk = 5  #Общее количество участков на снаряде
@@ -395,24 +416,28 @@ class OFSMCCSolver:
         hb = sizes['R17'] - (d / 2)   # Высота пояска
         xct = state['geometry_solver']['L_all'] - xc # Координата центра тяжести (ОТ НОСИКА !!!)
 
-
         R_d = d / 2
         # Колпачок взрывателя
+
         fuse_nose = {'type': 1, 'x1': 0., 'x2': sizes['R29'], 'r1': sizes['R28'], 'r2': sizes['R28'], 'R': 0., 'n': 0.}
+
         # Конус взрывателя
         fuse_korp = {'type': 2, 'x1': sizes['R29'], 'x2': sizes['R27'], 'r1': sizes['R28'], 'r2': sizes['R9'], 'R': 0., 'n': 0.}
+
         # Оживало снаряда
         h_oj = sizes['R27'] + sizes['R8']
         R_oj = state['geometry_solver']['Roj']
         shell_ojive = {'type': 4, 'x1': sizes['R27'], 'x2': h_oj, 'r1': sizes['R9'], 'r2': R_d, 'R': R_oj, 'n': 0.}
+
+
         # Цилиндр снаряда (до зпч)
         h_cyl = h_oj + sizes['R7'] + sizes['R6'] + sizes['R4'] + sizes['R3'] + sizes['R2']
         cyl_shell = {'type': 1, 'x1': h_oj, 'x2': h_cyl, 'r1': R_d, 'r2': R_d, 'R': 0., 'n': 0.}
+
+
         # Конус ЗПЧ
         r_zp = R_d - np.tan(sizes['R23']) * sizes['R1']
-        print(r_zp * 1000)
         zp_konus = {'type': 2, 'x1': h_cyl, 'x2': h_cyl + sizes['R1'], 'r1': R_d, 'r2': r_zp, 'R': 0., 'n': 0.}
-
         geometry_data = [fuse_nose, fuse_korp, shell_ojive, cyl_shell, zp_konus]
 
         result = {'ng': ng, 'nh': nh, 'nk': nk, 'nfl': nfl, 'yint': yint, 'd': d, 'hb': hb, 'xct': xct,
