@@ -306,6 +306,8 @@ class RandomOptimizer:
 
         tk = self.t0
 
+
+
         while steps_total < self.N:
             while bad_steps_cur < self.M:
                 try:
@@ -348,6 +350,7 @@ class RandomOptimizer:
                         x_history.append((np.copy(yj)))
 
                 except Exception as e:
+
                     if print_limit is not None:
                         traceback.print_exc(limit=print_limit)
                     bad_steps_cur += 1
@@ -382,6 +385,7 @@ class RandomOptimizer:
                              error_list=exception_list
                              )
 
+# Алгоритм 2022 года
 class SRandomOptimizer:
 
     def __init__(self, N=100, beta=1.0, min_delta_f=0., random_state=42):
@@ -390,147 +394,178 @@ class SRandomOptimizer:
         self.min_delta_f = min_delta_f
         self.random_state = random_state
 
-    # Определяет на каждом шаге размерность случайного подпространства
-    @staticmethod
-    def Sdv(MF, M01, k, m, KxM):
-        for j in range(m - 1, 0, -1):
-            MF[j] = MF[j - 1]
-            M01[j] = M01[j - 1]
-            for i in range(k):
-                KxM[i, j] = KxM[i, j - 1]
+        self.n0 = 0  # Число неудачных шагов из опорной точки
+        self.supn0 = 0  # Наибольшее число неудачных шагов из какой-либо опорной точки в процессе оптимизации
+        self.m = 5  # Число предшествующих шагов для адаптации поиска
+        self.k = None  # Число оптимизируемых параметров
+        self.rs = None
+        self.ss = None
+        self.MF = None
+        self.M01 = None
+        self.cod = None
+        self.mcod = self.beta  # Начальное значение коэфф. шага
+        self.KxM = None
+        self.PP = None
 
     # Вырабаытывает случайный шаг
-    def SHAG(self, n0, supn0, k, rs, ss, MF, M01, cod, mcod, m, KxM, PP):
-
-        mp = np.exp(-4.6 * ((n0 / self.N) ** 2 + (supn0 / self.N) ** 2)) / np.sqrt(k)
+    def SHAG(self):
+        mp = np.exp(-4.6 * ((self.n0 / self.N) ** 2 + (self.supn0 / self.N) ** 2)) / np.sqrt(self.k)
         su = 0
         sf = 0
 
-        for i in range(m):
-            sf = sf + MF[i]
-            su = su + M01[i]
+        for i in range(self.m):
+            sf = sf + self.MF[i]
+            su = su + self.M01[i]
 
-        for i in range(k):
-            cod[i] = 0.0
-            rs[i] = 0.0
-            ss[i] = 0.0
+        for i in range(self.k):
+            self.cod[i] = 0.0
+            self.rs[i] = 0.0
+            self.ss[i] = 0.0
 
             if np.abs(sf) > 1.0E-10:
-                for j in range(m):
-                    rs[i] = rs[i] - (j / m) * MF[j] * KxM[i, j]
-                rs[i] = rs[i] * su * su / (m * sf)
-                rs[i] = rs[i] * (su / m) * (sf / su)
-                ss[i] = -(su / m) * mp * np.random.randn()
-                cod[i] = rs[i] + ss[i]
+                for j in range(self.m):
+                    self.rs[i] = self.rs[i] - (j / self.m) * self.MF[j] * self.KxM[i, j]
+                self.rs[i] = self.rs[i] * su * su / (self.m * sf)
+                self.rs[i] = self.rs[i] * (su / self.m) * (sf / su)
+                self.ss[i] = -(su / self.m) * mp * np.random.randn()
+                self.cod[i] = self.rs[i] + self.ss[i]
             else:
-                cod[i] = mp * np.random.randn()
+                self.cod[i] = mp * np.random.randn()
 
-            cod[i] = PP[i] + mcod * cod[i]
+            self.cod[i] = self.PP[i] + self.mcod * self.cod[i]
 
-            if cod[i] < 0.0:
-                cod[i] = 0.0
-            if cod[i] > 1.0:
-                cod[i] = 1.0
+            if self.cod[i] < 0.0:
+                self.cod[i] = 0.0
+            if self.cod[i] > 1.0:
+                self.cod[i] = 1.0
 
-    def optimize(self, problem: OptProblem, print_limit=1):
+    # Определяет на каждом шаге размерность случайного подпространства
+    def Sdv(self):
+        for j in range(self.m - 1, 0, -1):
+            self.MF[j] = self.MF[j - 1]
+            self.M01[j] = self.M01[j - 1]
+            for i in range(self.k):
+                self.KxM[i, j] = self.KxM[i, j - 1]
 
+
+    def optimize(self, problem: OptProblem, print_limit=None):
         np.random.seed(self.random_state)
-        # Инициализируем переменные
+        global_state_history = []
+        f_history = []
+        mask = []
+        exception_list = []
+        x_history = []
+        steps_total = 0
+        bad_steps_cur = 0
+        Flag = False
+        f_evals = 0
+        f_evals_errs = 0
         x0, bounds = problem.get_x0_w_bounds()
+        last_x = np.copy(x0)  # ВВП оразмеренный
 
-        k = len(x0)  # Число оптимизируемых параметров
-        lims = bounds.copy()  # Ограничения 1 рода
+        # Инициализируем переменные
+        self.k = len(x0)
+        # lims = np.array([bound.to_list() for bound in bounds])  # Ограничения 1 рода
 
         xx = x0.copy()  # Вектор в размерном виде
-        last_xx = x0.copy()  # Прерыдущие значения вектора в обезразмеренном виде
+        last_xx = x0.copy()  # Прерыдущие значения вектора в размерном виде
 
-        cod = (x0 - lims[:, 0]) / ((lims[:, 1]) - lims[:, 0])  # Вектор кодовых параметров
+        self.cod = (x0 - bounds[:, 0]) / ((bounds[:, 1]) - bounds[:, 0])  # Вектор кодовых параметров
+        last_cod = self.cod.copy()  # предыдущие значения кодового вектора
 
-        last_cod = cod.copy()  # предыдущие значения кодового вектора
+        cur_f = np.inf
+        last_f = np.inf
 
-        m = 5  # Число предшествующих шагов для адаптации поиска
-        PP = np.zeros(k)  # Сохраняет параметры опорной точки(в конце оптимизации содержит оптимальные точки)
-        KxM = np.zeros(
-            (k, m))  # Содержит приращения компонента после каждого удачного шага в последовательсти m предш. шагов
-        MF = np.zeros(m)  # Содержит приращения ЦФ на каждом удачном шаге
-        M01 = np.zeros(m)  # Содержит успех каждого предшествующего шага (состоит из 0 и 1)
-        rs = np.zeros(k)
-        ss = np.zeros(k)
+        self.PP = np.zeros(self.k)  # Сохраняет параметры опорной точки(в конце оптимизации содержит оптимальные точки)
+        self.KxM = np.zeros(
+            (self.k, self.m))  # Содержит приращения компонента после каждого удачного шага в последовательсти m предш. шагов
+        self.MF = np.zeros(self.m)  # Содержит приращения ЦФ на каждом удачном шаге
+        self.M01 = np.zeros(self.m)  # Содержит успех каждого предшествующего шага (состоит из 0 и 1)
+        self.rs = np.zeros(self.k)
+        self.ss = np.zeros(self.k)
 
-        search_history_x = []
-        search_history_f = []
-        global_state_history = []
 
-        Flag = False
-        n0 = 0  # Число неудачных шагов из опорной точки
-        supn0 = 0  # Наибольшее число неудачных шагов из какой-либо опорной точки в процессе оптимизации
-        f_evals = 0
-        mcod = self.beta  # Начальное значение коэфф. шага
-        cur_f = 1.0E+300
-        last_f = 1.0E+300
 
-        f_evals_errs = 0
 
-        while n0 <= self.N:
+
+
+
+        while self.n0 <= self.N:
+            xx = bounds[:, 0] + (bounds[:, 1] - bounds[:, 0]) * self.cod  # Оразмеривание
+            print(self.cod)
             try:
-                xx = lims[:, 0] + (lims[:, 1] - lims[:, 0]) * cod  # Оразмеривание
-                # Проверка ограничений
-
                 cur_f = problem(xx)
-                f_evals += 1
-
-                # Проверка условий
-                if (cur_f < last_f) & (abs(cur_f - last_f) > self.min_delta_f):
-                    # Шаг удачный
-                    n0 = 0
-                    if Flag:
-                        self.Sdv(MF, M01, k, m, KxM)
-                        MF[0] = cur_f - last_f
-                        M01[0] = 1
-                        for i in range(k):
-                            KxM[i, 0] = cod[i] - PP[i]
-
-                    Flag = True
-                    last_f = cur_f
-                    last_cod = cod.copy()
-                    last_xx = xx.copy()
-                    problem.callback()
-
-                    # print('Удачный шаг, Сf=',f)
-
-                    for i in range(k):
-                        PP[i] = cod[i]
-
-                    search_history_x.append(last_xx.copy())
-                    search_history_f.append(last_f)
-                    global_state_history.append(deepcopy(problem.global_state))
-
-                else:
-                    # Шаг неудачный
-                    n0 += 1
-                    if n0 > supn0:
-                        supn0 = n0
-                    self.Sdv(MF, M01, k, m, KxM)
-                    MF[0] = 0
-                    M01[0] = 0
-                    for i in range(k):
-                        KxM[i, 0] = 0
-
-                self.SHAG(n0, supn0, k, rs, ss, MF, M01, cod, mcod, m, KxM, PP)
-
             except:
-                if print_limit is not None:
-                    traceback.print_exc(limit=print_limit)
-                n0 += 1
-                f_evals_errs += 1
+                cur_f = np.inf
+
+            # Проверка условий
+            if (cur_f < last_f) & (abs(cur_f - last_f) > self.min_delta_f):
+                # Шаг удачный
+                print('Удачный')
+                self.n0 = 0
+                if Flag:
+                    self.Sdv()
+                    self.MF[0] = cur_f - last_f
+                    self.M01[0] = 1
+                    for i in range(self.k):
+                        self.KxM[i, 0] = self.cod[i] - self.PP[i]
+
+                Flag = True
+                last_f = cur_f
+                last_cod = self.cod.copy()
+                last_xx = xx.copy()
+
+                global_state_history.append(deepcopy(problem.global_state))
+                f_history.append(last_f)
+                x_history.append(np.copy(last_xx))
+                mask.append(1)
+                problem.callback()
+
+                for i in range(self.k):
+                    self.PP[i] = self.cod[i]
+
+            else:
+                # Шаг неудачный
+                self.n0 += 1
+                if self.n0 > self.supn0:
+                    self.supn0 = self.n0
+                self.Sdv()
+                self.MF[0] = 0
+                self.M01[0] = 0
+                for i in range(self.k):
+                    self.KxM[i, 0] = 0
+
+                mask.append(0)
+                f_history.append(cur_f)
+                x_history.append(np.copy(xx))
+
+            self.SHAG()
 
         # Выход из оптимизации
-        cur_f = last_f
-        for i in range(k):
-            cod[i] = PP[i]
+        f_history = np.array(f_history)
+        x_history = np.array(x_history)
+        mask = np.array(mask).astype(bool)
+
+        if not Flag:
+            return OptResult(x_history=x_history,
+                             f_history=f_history,
+                             step_mask=mask,
+                             global_state_history=global_state_history,
+                             status_code=1,
+                             status_message='Оптимизация завершилась неудачно, т.к. не найдено ни одного оптимума',
+                             error_list=exception_list
+                             )
+        else:
+            return OptResult(x_history=x_history,
+                             f_history=f_history,
+                             step_mask=mask,
+                             global_state_history=global_state_history,
+                             status_code=0,
+                             status_message='Оптимизация завершилась удачно по критерию останова',
+                             error_list=exception_list
+                             )
+
 
-        if Flag:
-            return last_xx, last_f, search_history_x, search_history_f, global_state_history
 
 class ConstrainedOptimizer:
 
