@@ -1190,7 +1190,7 @@ class BeltZoneSolver:
                     x = (qPR - (qp - (dq_dKSI_BC * KSI))) / dq_dKSI_BC
                     return x
 
-            return W0
+            return W0, qp
 
 
         p_data = self.preprocessed_data
@@ -1250,14 +1250,14 @@ class BeltZoneSolver:
 
     # 1. Остаточные деформации корпуса снаряда в зоне ведущего пояска
 
-        # Определение текущего и остаточного значения прогиба стенки
-        W0_curr = calc_coef(lambd, qN_g=None, qPR=None)
+        # Определение текущего и остаточного значения прогиба стенки и реакции пояска в момент врезания
+        W0_curr, qp = calc_coef(lambd, qN_g=None, qPR=None)
 
 
         if W0_curr < a0 * eps_sh:
             res['stat_deform'] = 'elastic'
             curr_lambda = 0
-            W0_curr = calc_coef(curr_lambda, qN_g=None, qPR=None)
+            W0_curr, qp = calc_coef(curr_lambda, qN_g=None, qPR=None)
             if W0_curr <= W5:
                 eta = (a0 * W5) / (a5 * W0_curr)
             else:
@@ -1267,7 +1267,7 @@ class BeltZoneSolver:
         else:
             res['stat_deform'] = 'plastic'
             curr_lambda = lambd
-            W0_curr = calc_coef(curr_lambda, qN_g=None, qPR=None)
+            W0_curr, qp = calc_coef(curr_lambda, qN_g=None, qPR=None)
 
             if W0_curr <= W5:
                 eta = (a0 * W5) / (a5 * W0_curr)
@@ -1298,6 +1298,7 @@ class BeltZoneSolver:
         res['W0_curr'] = W0_curr
         res['a0'] = a0
         res['eps_sh'] = eps_sh
+        res['qp'] = qp
 
     # 2. Расчёт прочности ведущего пояска на срез
 
